(this.webpackJsonpstreamlit_pagnation=this.webpackJsonpstreamlit_pagnation||[]).push([[0],{14:function(e,t,n){e.exports=n(22)},21:function(e,t,n){},22:function(e,t,n){"use strict";n.r(t);var a=n(5),r=n.n(a),o=n(12),s=n.n(o),c=n(0),i=n(1),l=n(2),u=n(3),f=n(8),b=(n(21),function(e){Object(l.a)(n,e);var t=Object(u.a)(n);function n(e){var a;return Object(i.a)(this,n),(a=t.call(this,e)).render=function(){var e=a.props.args.pages,t=a.props.args.max,n=a.props.args.hvrclr,o=a.props.args.atvclr;return r.a.createElement("span",null,r.a.createElement("style",null,".btn:hover:not(.active) {\n                background-color: ".concat(n,";\n              }\n             .btn.active {\n                background: ").concat(o,";\n             }")),r.a.createElement("div",{className:"pagnation"},r.a.createElement("div",null,"\xa0"),r.a.createElement("button",{className:"btn",onClick:function(){return a.state.pageNumber>1?a.onClickPrevOrNext(a.state.pageNumber-1,t):a.onClickPrevOrNext(1,t)},style:{visibility:a.state.pageNumber>1?"visible":"hidden"}},"Prev"),null===e||void 0===e?void 0:e.filter((function(e){return t>0?e>a.state.offset&&e<a.state.offset+t+1?e:void 0:e})).map((function(e){return r.a.createElement("button",{className:a.state.pageNumber==e?"btn active":"btn",onClick:function(t){return a.onClickNumber(e)}},e)})),r.a.createElement("button",{className:"btn",onClick:function(){return a.state.pageNumber<e[e.length-1]?a.onClickPrevOrNext(a.state.pageNumber+1,t):a.onClickPrevOrNext(e[e.length-1],t)},style:{visibility:a.state.pageNumber<e[e.length-1]?"visible":"hidden"}},"Next")))},a.onClickNumber=function(e){a.setState((function(t){return{pageNumber:e,clickPrevOrNext:!1}}),(function(){return f.a.setComponentValue(a.state.pageNumber)}))},a.onClickPrevOrNext=function(e,t){a.state.offset+t<e?a.setState({offset:a.state.offset+1}):a.state.offset+1>e&&a.state.offset>0&&a.setState({offset:a.state.offset-1}),a.setState((function(t){return{pageNumber:e,clickPrevOrNext:!0}}),(function(){f.a.setComponentValue(a.state.pageNumber)}))},a.state={pageNumber:1,clickPrevOrNext:!1,offset:0},f.a.setComponentValue(1),a}return Object(c.a)(n)}(f.b)),m=Object(f.c)(b);s.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(m,null)),document.getElementById("root"))}},[[14,1,2]]]);
//# sourceMappingURL=main.3ac2dffb.chunk.js.map