body{background-color:initial!important;color:#5a6674!important;font-size:13px;font-family:"Roboto",sans-serif;display:flex;justify-content:center;height:65px}.btn{background:none;outline:none!important;border:none!important;color:#fff;align-self:center;padding:8px 16px;text-decoration:none;left:50%;top:50%}.btn.active{background:#4caf50;color:#fff}.btn:focus{border:none;outline:none}.btn:hover:not(.active){background-color:#ddd}
/*# sourceMappingURL=main.004acf31.chunk.css.map */